%BGSS    is a driver for BALGROWTH.M which computes the balanced growth
%        steady state for the model in 
%
%             McGrattan and Prescott
%             Openness, Technology Capital, and Development
%

%        Ellen McGrattan, 3-13-07
%        Revised, ERM, 9-21-07


I        = 2;
N        = [10,1]';
Z        = [1,1]';
sigma    = .85*ones(I,1);
alpha    = .3;
beta     = .98;
deltk    = .053;
deltm    = .1;
gamN     = .01;
gamY     = .029392;
phi      = .07;
psi      = 2.5;
%
%With inelastic labor and no growth:
%
%gamN    = 0;
%gamY    = 0;
%beta    = 1/1.04;
%psi     = 0.000001;
%
A        = Z.^(1-alpha*(1-phi));
constant = [alpha;beta;deltk;deltm;gamN;gamY;phi;psi];
V        = balgrowth(N,A,sigma,constant);
y        = V(:,1);
c        = V(:,2);
xk       = V(:,3);
xm       = V(:,4);
l        = V(:,5);
k        = V(:,6);
mhat     = V(:,7);
m        = V(:,8);
nx       = V(:,9);

disp('Balanced Growth Steady State')
disp('----------------------------')
disp(sprintf('    Number of countries: %g',length(N)))
disp(' ')
disp('    Key Inputs:')
disp('                                 Total factor      Degree of ')
disp('                 Population      Productivity      Openness')
disp('                 ---------------------------------------------')
disp(sprintf('                  %7.3f %15.3f %15.3f \n',[N,A,sigma]'))
disp('    Key Outputs:')
disp('                                 Per capita        Technology') 
disp('                 Productivity    Consumption       Capital   ')
disp('                 --------------------------------------------')
disp(sprintf('                  %7.3f %15.3f %15.3f \n',[y./l,c,m]'))

