% ******************************************************************* %
% CODE PLOTS FIGURES FOR
%           McGrattan & Prescott, "Openness, Technology Capital 
%                                   and Development", WP 651
%
% CODE READS IN DATA FROM EXCEL FILE: ForMatlab_ReadOnly.xls
%
%   Simona E. Cociuba
%   April, 2007
% ******************************************************************* %

clear; clc;

% READ IN DATA
[Data, Labels]  = xlsread('LaborProductivity.xls','Matlab');

    time    = Data(:,1);
    EU6     = Data(:,2);
    J73     = Data(:,3);    % countries that joined EU in 1973
    J95     = Data(:,4);    % countries that joined EU in 1995
    Switz   = Data(:,5);    % Switerland
    CE8     = Data(:,6);    % Central European Countries joined EU in 2004
    SA      = Data(:,7);    % Data for South America
    Asia    = Data(:,8);    % Data for Asia

% READ IN DATA FROM ELLEN'S CODE
load Figure8;
load Figure9;
load Figure10.dat;
load Figure11.dat;
load Figure12.dat;
load Figure13.dat;
load Figure14.dat;
load Figure15.dat;

fprintf('DO YOU WANT TO ...\n'); 
fprintf('\n');
Var = input( '   1 = Plot data, or\n\n   2 = Plot numerical examples, or\n\n   3 = Plot all graphs for slides(i.e. bigger font)?\n\n');
fprintf('\n');

% PARAMETERS TO BE USED IN PLOTS
	lw  = 3;            % linewidth
	fwl = 'normal';     % fontweight label
        fn  = 'cmr10';      % font name        
        fsl = 22;           % fontsize label
               
if Var == 1
    figure(1)
        hh=axes('Position', [.1 .07 .86 .86 ] );
        hold
        plot(time(1:50), EU6(1:50),'bd','LineWidth',lw, 'MarkerSize', 4.5, 'MarkerFaceColor', 'b')
        line(time(50:106), EU6(50:106),'LineWidth',lw)
        line([1957 1957],[40,110],'LineWidth',.1,'LineStyle',':','Color','k')
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1900, 2006])
        set(gca,'xtick', [1900 1920 1940 1960 1980 2000])
        ylim([40, 110])
        set(gca,'ytick', [40 50 60 70 80 90 100 110])
        set(gca,'YTickLabel', {' ' '50 ' '60 ' '70 ' '80 ' '90 ' '100 ' '%110 '})
                text(1905,105,'EU-6', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(1908,100,'Belgium', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1908, 96,'France', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1908, 92,'Italy', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1908, 88,'Luxembourg', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1908, 84,'Netherlands', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1908, 80,'West Germany', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');

    figure(2)
        hh=axes('Position', [.1 .07 .86 .86 ]);
        hold
        plot(time(61:106), J73(61:106),'LineWidth',lw)
        line([1973 1973],[70 110],'LineWidth',.1,'LineStyle',':','Color','k')
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([70, 110])
        set(gca,'ytick', [70 80 90 100 110])
        set(gca,'YTickLabel', {' ' '80 ' '90 ' '100 ' '%110 '})
                text(1973.5,105,'1973 Joiners ', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(1975.5,102.12,'Denmark', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1975.5, 99.81,'Ireland', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1975.5, 97.5,'U.K.', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');

    figure(3)
        hh=axes('Position', [.1 .07 .86 .86 ]);
        hold
        plot(time(61:106), J95(61:106),'LineWidth',lw)
        line([1995 1995],[70 110],'Linewidth',.5,'LineStyle',':','Color','k')
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([70, 110])
        set(gca,'ytick', [70 80 90 100 110])
        set(gca,'YTickLabel', {' ' '80 ' '90 ' '100 ' '%110 '})
                text(1995.5,105,'1995 Joiners ', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(1997.5,102.12,'Austria', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1997.5, 99.81,'Finland', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1997.5, 97.5,'Sweden', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');

    figure(4)
        hh=axes('Position', [.1 .07 .86 .86 ]);
        hold
        plot(time(61:106), Switz(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([60, 160])
        set(gca,'ytick', [60 80 100 120 140 160])
        set(gca,'YTickLabel', {' ' '80 ' '100 ' '120 ' '140 ' '%160 '})
              %text(1995,148,'Switzerland ', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(5)
        hh=axes('Position', [.1 .07 .86 .86 ]);
        hold
        plot(time(90:106), CE8(90:106),'LineWidth',lw)
        line([2004 2004],[25 40],'LineWidth',.1,'LineStyle',':','Color','k')
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1989, 2006])
        set(gca,'xtick', [1989 1991 1993 1995 1997 1999 2001 2003 2005])
        ylim([25, 40])
        set(gca,'ytick', [25 30 35 40])
        set(gca,'YTickLabel', {' ' '30 ' '35 ' '%40 '})
                text(1990,39,'CE-8', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,37.88,'Czech Republic', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,36.98,'Estonia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,36.08,'Hungary', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,35.18,'Latvia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,34.28,'Lithuania', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,33.38,'Poland', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,32.48,'Slovakia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1990.4,31.58,'Slovenia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');

    figure(6)
        hh=axes('Position', [.1 .07 .86 .86 ]);
        hold
        plot(time(61:106), SA(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([0 45])
        set(gca,'ytick', [5 15 25 35 45])
        set(gca,'YTickLabel', {'5 ' '15 ' '25 ' '35 ' '%45 '})
                text(1962,30,'South America', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(1963,27,'Argentina', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963,24.5,'Bolivia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963,22,'Brazil', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963,19.5,'Chile', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963,17,'Colombia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963,14.5,'Ecuador', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963, 12,'Peru', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963, 9.5,'Uruguay', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1963, 7,'Venezuela', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');

    figure(7)
        hh=axes('Position', [.1 .07 .86 .86 ]);
        hold
        plot(time(61:106), Asia(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([0 18])
        set(gca,'ytick', [0 6 12 18])
        set(gca,'YTickLabel', {' ' '6 ' '12 ' '%18 '})
                text(1994,13,'Asia', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(1995,11.8,'China', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995,10.95,'Hong Kong', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995,10.1,'India', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 9.25,'Indonesia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 8.4,'Japan', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 7.55,'Malaysia', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 6.7,'Pakistan', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 5.85,'Philippines', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 5.0,'Singapore', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 4.15,'South Korea', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 3.3,'Taiwan', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
                text(1995, 2.45,'Thailand', 'FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10');
elseif Var == 2
    figure(8)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure8(:,1), Figure8(:,2),'b','LineWidth',lw+1.5)
        plot(Figure8(:,1), Figure8(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName', ...
            fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Fraction of FDI Permitted, \omega')
        %ylabel('Productivity','FontSize',fsl-2,'FontWeight', ....
        %    fwl,'FontName','dccsc10')
        xlim([0, 1])
        set(gca,'xtick', [0 0.2 0.4 0.6 0.8 1.0])
        ylim([95, 130])
        set(gca,'ytick', [95 100 105 110 115 120 125 130])
        set(gca,'YTickLabel',  ...
            {'95 ' '100 ' '105 ' '110 ' '115 ' '120 ' '125 ' '%130 '})
            text(0.2,126,'Big Country', 'FontSize',fsl-1,'FontWeight', ...
                 fwl,'FontName','dccsc10');
            text(0.5,115,'Small Country', 'FontSize',fsl-1,'FontWeight', ...
                 fwl,'FontName','dccsc10');

    figure(9)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure9(:,1), Figure9(:,2),'b','LineWidth',lw+1.5)
        plot(Figure9(:,1), Figure9(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName', ...
            fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Fraction of FDI Permitted, \omega')
        %ylabel('Technology Capital Share','FontSize',fsl-2,'FontWeight', ...
        %        fwl,'FontName','dccsc10')
        xlim([0, 1])
        set(gca,'xtick', [0 0.2 0.4 0.6 0.8 1.0])
        ylim([0, .6])
        set(gca,'ytick', [0 0.1 0.2 0.3 0.4 0.5 0.6])
        set(gca,'YTickLabel', {'0 ' '0.1 ' '0.2 ' '0.3 ' '0.4 ' '0.5 ' '0.6 '})
            text(0.2,.58,'Big Country', 'FontSize',fsl-1,'FontWeight', ...
                 fwl,'FontName','dccsc10');
            text(0.1,.1,'Small Country', 'FontSize',fsl-1,'FontWeight', ...
                 fwl,'FontName','dccsc10');

    figure(10)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure10(:,1), Figure10(:,2),'b','LineWidth',lw+1.5)
        plot(Figure10(:,1), Figure10(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0, 1])
        set(gca,'ytick', [0 0.2 0.4 0.6 0.8 1 ])
        set(gca,'YTickLabel', {'0 ' '0.2 ' '0.4 ' '0.6 ' '0.8 ' '1.0 '})
                text(2,0.94,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(21,0.6,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(11)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure11(:,1), Figure11(:,2),'b','LineWidth',lw+1.5)
        plot(Figure11(:,1), Figure11(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([85, 130])
        set(gca,'ytick', [85 100 115 130])
        set(gca,'YTickLabel', {'85 ' '100 ' '115 ' '%130 '})
                text(2,121,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(13,108,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(12)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure12(:,1), Figure12(:,2)/100,'b','LineWidth',lw+1.5)
        plot(Figure12(:,1), Figure12(:,3)/100,'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0, 7])
        set(gca,'ytick', [0 1 2 3 4 5 6 7])
        set(gca,'YTickLabel', {'0 ' '1 ' '2 ' '3 ' '4 ' '5 ' '6 ' '7 '})
                text(27.5,5.25,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(27.5,1.60,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(13)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure13(:,1), Figure13(:,2),'b','LineWidth',lw+1.5)
        plot(Figure13(:,1), Figure13(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0, 1])
        set(gca,'ytick', [0 0.2 0.4 0.6 0.8 1 ])
        set(gca,'YTickLabel', {'0 ' '0.2 ' '0.4 ' '0.6 ' '0.8 ' '1.0 '})
                text(5,0.85,'Opens First', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(24,0.5,'Opens Second', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(14)
        hh=axes('Position', [.1 .1 .83 .83 ]);
        hold
        plot(Figure14(:,1), Figure14(:,2)/100,'b','LineWidth',lw+1.5)
        plot(Figure14(:,1), Figure14(:,3)/100,'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0.30, 0.70])
        set(gca,'ytick', [0.30 0.40 0.50 0.60 0.70])
        set(gca,'YTickLabel', {'0.3 ' '0.4 ' '0.5 ' '0.6 ' '0.7 '})
                text(32,0.65,'Opens Second', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(15,0.40,'Opens First', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(15)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(Figure15(:,1), Figure15(:,2),'r','LineWidth',lw+1.5)
        plot(Figure15(:,1), Figure15(:,3),'g','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([85, 145])
        set(gca,'ytick', [85 100 115 130 145])
        set(gca,'YTickLabel', {'85 ' '100 ' '115 ' '130 ' '%145 '})
                text(30,117,'A_{2,t}=A_{1,t}', 'FontSize',fsl-1,'FontWeight',fwl,'FontName',fn);
                text(30,135,'A_{2,t}=A_{1,t}(0.9+0.1\sigma_{2,t})', 'FontSize',fsl-1,'FontWeight',fwl,'FontName',fn);

elseif Var == 3
    
    fsl = 34;
    
        figure(1)
        hh=axes('Position', [.1 .1 .86 .86 ] );
        hold
        plot(time(1:50), EU6(1:50),'bd','LineWidth',lw, 'MarkerSize', 4.5, 'MarkerFaceColor', 'b')
        plot(time(50:106), EU6(50:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1900, 2006])
        set(gca,'xtick', [1900 1920 1940 1960 1980 2000])
        ylim([40, 110])
        set(gca,'ytick', [40 50 60 70 80 90 100 110])
        set(gca,'YTickLabel', {' ' '50 ' '60 ' '70 ' '80 ' '90 ' '100 ' '%110 '})
                text(1905,105,'EU-6', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                
    figure(2)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(time(61:106), J73(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([70, 110])
        set(gca,'ytick', [70 80 90 100 110])
        set(gca,'YTickLabel', {' ' '80 ' '90 ' '100 ' '%110 '})
                text(1963,105,'1973 Joiners ', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                
    figure(3)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(time(61:106), J95(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([70, 110])
        set(gca,'ytick', [70 80 90 100 110])
        set(gca,'YTickLabel', {' ' '80 ' '90 ' '100 ' '%110 '})
                text(1963,105,'1995 Joiners ', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                
    figure(4)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(time(61:106), Switz(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([60, 160])
        set(gca,'ytick', [60 80 100 120 140 160])
        set(gca,'YTickLabel', {' ' '80 ' '100 ' '120 ' '140 ' '%160 '})
                text(1963,148,'Switzerland ', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(5)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(time(90:106), CE8(90:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1989, 2006])
        set(gca,'xtick', [1989 1993 1997 2001 2005])
        ylim([25, 40])
        set(gca,'ytick', [25 30 35 40])
        set(gca,'YTickLabel', {' ' '30 ' '35 ' '%40 '})
                text(1999,36,'CE-8', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                
    figure(6)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(time(61:106), SA(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([0 45])
        set(gca,'ytick', [5 15 25 35 45])
        set(gca,'YTickLabel', {'5 ' '15 ' '25 ' '35 ' '%45 '})
                text(1962,30,'South America', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                
    figure(7)
        hh=axes('Position', [.1 .1 .86 .86 ]);
        hold
        plot(time(61:106), Asia(61:106),'LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlim([1960, 2006])
        set(gca,'xtick', [1960 1970 1980 1990 2000])
        ylim([0 18])
        set(gca,'ytick', [0 6 12 18])
        set(gca,'YTickLabel', {' ' '6 ' '12 ' '%16 '})
                text(1994,15.5,'Asia', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
       
    figure(8)
        hh=axes('Position', [.15 .13 .80 .83 ]);
        hold
        plot(Figure8(:,1), Figure8(:,2),'b','LineWidth',lw+1.5)
        plot(Figure8(:,1), Figure8(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Fraction of FDI Permitted, \omega')
        %ylabel('Productivity','FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10')
        xlim([0, 1])
        set(gca,'xtick', [0 0.2 0.4 0.6 0.8 1.0])
        ylim([95, 130])
        set(gca,'ytick', [95 100 105 110 115 120 125 130])
        set(gca,'YTickLabel', {'95 ' '100 ' '105 ' '110 ' '115 ' '120 ' '125 ' '%130 '})
                text(0.2,126,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(0.5,115,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(9)
        hh=axes('Position', [.13 .13 .83 .83 ]);
        hold
        plot(Figure9(:,1), Figure9(:,2),'b','LineWidth',lw+1.5)
        plot(Figure9(:,1), Figure9(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Fraction of FDI Permitted, \omega')
        %ylabel('Technology Capital','FontSize',fsl-2,'FontWeight',fwl,'FontName','dccsc10')
        xlim([0, 1])
        set(gca,'xtick', [0 0.2 0.4 0.6 0.8 1.0])
        ylim([0, .6])
        set(gca,'ytick', [0 0.1 0.2 0.3 0.4 0.5 0.6])
        set(gca,'YTickLabel', {'0 ' '0.1 ' '0.2 ' '0.3 ' '0.4 ' '0.5 ' '0.6 '})
                text(0.2,.58,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(0.1,.1,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(10)
        hh=axes('Position', [.11 .13 .83 .83 ]);
        hold
        plot(Figure10(:,1), Figure10(:,2),'b','LineWidth',lw+1.5)
        plot(Figure10(:,1), Figure10(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0, 1])
        set(gca,'ytick', [0 0.2 0.4 0.6 0.8 1 ])
        set(gca,'YTickLabel', {'0 ' '0.2 ' '0.4 ' '0.6 ' '0.8 ' '1.0 '})
                text(2,0.94,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(21, 0.6,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(11)
        hh=axes('Position', [.13 .13 .83 .83 ]);
        hold
        plot(Figure11(:,1), Figure11(:,2),'b','LineWidth',lw+1.5)
        plot(Figure11(:,1), Figure11(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([85, 130])
        set(gca,'ytick', [85 100 115 130])
        set(gca,'YTickLabel', {'85 ' '100 ' '115 ' '%130 '})
                text(2,127,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(13,108,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(12)
        hh=axes('Position', [.11 .13 .83 .83 ]);
        hold
        plot(Figure12(:,1), Figure12(:,2)/100,'b','LineWidth',lw+1.5)
        plot(Figure12(:,1), Figure12(:,3)/100,'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0, 7])
        set(gca,'ytick', [0 1 2 3 4 5 6 7])
        set(gca,'YTickLabel', {'0 ' '1 ' '2 ' '3 ' '4 ' '5 ' '6 ' '7 '})
                text(27.5,5.25,'Big Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(27.5,1.60,'Small Country', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(13)
        hh=axes('Position', [.11 .13 .83 .83 ]);
        hold
        plot(Figure13(:,1), Figure13(:,2),'b','LineWidth',lw+1.5)
        plot(Figure13(:,1), Figure13(:,3),'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0, 1])
        set(gca,'ytick', [0 0.2 0.4 0.6 0.8 1.0])
        set(gca,'YTickLabel', {'0 ' '0.2 ' '0.4 ' '0.6 ' '0.8 ' '1.0 '})
                text(2,0.92,'Opens First', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(24,0.5,'Opens Second', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(14)
        hh=axes('Position', [.11 .13 .83 .83 ]);
        hold
        plot(Figure14(:,1), Figure14(:,2)/100,'b','LineWidth',lw+1.5)
        plot(Figure14(:,1), Figure14(:,3)/100,'r','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([0.30, 0.70])
        set(gca,'ytick', [0.30 0.40 0.50 0.60 0.70])
        set(gca,'YTickLabel', {'0.3 ' '0.4 ' '0.5 ' '0.6 ' '0.7 '})
                text(32,0.65,'Opens Second', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');
                text(11,0.35,'Opens First', 'FontSize',fsl-1,'FontWeight',fwl,'FontName','dccsc10');

    figure(15)
        hh=axes('Position', [.13 .13 .83 .83 ]);
        hold
        plot(Figure15(:,1), Figure15(:,2),'r','LineWidth',lw+1.5)
        plot(Figure15(:,1), Figure15(:,3),'g','LineWidth',lw)
        set(gca,'FontSize',fsl,'FontWeight',fwl,'FontName',fn,'YGrid','off','XGrid','off', 'TickDir', 'out')
        xlabel('Years')
        xlim([0, 60])
        set(gca,'xtick', [0 10 20 30 40 50 60])
        ylim([85, 145])
        set(gca,'ytick', [85 100 115 130 145])
        set(gca,'YTickLabel', {'85 ' '100 ' '115 ' '130 ' '%145 '})
                text(30,117,'A_{2,t}=A_{1,t}', 'FontSize',fsl-1,'FontWeight',fwl,'FontName',fn);
                text(30,135,'A_{2,t}=A_{1,t}(0.9+0.1\sigma_{2,t})', 'FontSize',fsl-1,'FontWeight',fwl,'FontName',fn);

end
